@@ -53,12 +53,13 @@ RecursiveAttrs = Mapping[str, 'SchemaType']  # type: ignore
 
 class ObjectWithAdditionalProperties(NamedTuple):
     type: Literal['object']
-    additional_properties: Mapping[str, Any]
+    additional_properties: Optional['SchemaType'] = None  # type: ignore
 
 
 class ArrayValue(NamedTuple):
     type: Literal['array']
     items: 'SchemaType'  # type: ignore
+    description: str = ''
 
 
 class ObjectValue(NamedTuple):
